sharlatan pushed a commit to branch go-team
in repository guix.

commit 0f2e43be28ab34379244da6bcb8ecc99476f2537
Author: Sharlatan Hellseher <[email protected]>
AuthorDate: Fri Dec 13 17:00:06 2024 +0000

    gnu: go-go-uber-org-zap: Update to 1.27.0.
    
    * gnu/packages/golang-xyz.scm (go-go-uber-org-zap): Update to 1.27.0.
    [arguments]<test-flags>: Skip 3 tests.
    <phases>: Remove 'remove-test-files, add 'remove-examples-and-benchamrks.
    [propagated-inputs]: Remove go-github-com-benbjohnson-clock,
    go-github-com-pkg-errors, go-go-uber-org-atomic, and
    go-gopkg-in-yaml-v2; add go-gopkg-in-yaml-v3.
    [native-inputs]: Remove go-golang-org-x-lint and go-honnef-co-go-tools.
    
    Change-Id: I3f2d90ce093f9aac4342ed887cc3a96419a281a9
---
 gnu/packages/golang-xyz.scm | 44 ++++++++++++++++++++++++++------------------
 1 file changed, 26 insertions(+), 18 deletions(-)

diff --git a/gnu/packages/golang-xyz.scm b/gnu/packages/golang-xyz.scm
index c9cd492484..f79a211d0f 100644
--- a/gnu/packages/golang-xyz.scm
+++ b/gnu/packages/golang-xyz.scm
@@ -9692,7 +9692,7 @@ applications out of reusable, composable modules.")
 (define-public go-go-uber-org-zap
   (package
     (name "go-go-uber-org-zap")
-    (version "1.24.0")
+    (version "1.27.0")
     (source
      (origin
        (method git-fetch)
@@ -9701,32 +9701,40 @@ applications out of reusable, composable modules.")
              (commit (string-append "v" version))))
        (file-name (git-file-name name version))
        (sha256
-        (base32 "0lzbbs87fvixzbyv4wpl3s70vm2m0jz2jgdvrviiksc2al451qgs"))))
+        (base32 "1h3ml2wqmdxwqv0xdfqvf7l4wma5yd0hdfsa6189mmbhkhzn8v3m"))))
     (build-system go-build-system)
     (arguments
      (list
       #:import-path "go.uber.org/zap"
+      #:test-flags
+      #~(list "-skip" (string-join
+                       ;; Unexpected stack trace annotation.
+                       (list "TestAddStackSkip"
+                             ;; Expected to find package name and file name in
+                             ;; output.
+                             "TestLoggerAddCaller"
+                             "TestSugarAddCaller")
+                       "|"))
       #:phases
       #~(modify-phases %standard-phases
-          ;; Remove test files requiring to download all dependencies for the
-          ;; current Go module and reports their module paths and locations on
-          ;; disk.
-          (add-after 'unpack 'remove-test-files
-            (lambda* (#:key import-path #:allow-other-keys)
-              (delete-file
-               (string-append "src/" import-path
-                              "/stacktrace_ext_test.go")))))))
+          (add-after 'unpack 'remove-examples-and-benchmarks
+            (lambda* (#:key tests? import-path #:allow-other-keys)
+              (with-directory-excursion (string-append "src/" import-path)
+                (for-each delete-file-recursively
+                          (list "benchmarks"
+                                ;; Remove test files requiring to download all
+                                ;; dependencies for the current Go module and
+                                ;; reports their module paths and locations on
+                                ;; disk.
+                                "stacktrace_ext_test.go"
+                                ;; Not packed yet google.golang.org/grpc.
+                                "zapgrpc/internal/test/grpc_test.go"))))))))
     (native-inputs
      (list go-github-com-stretchr-testify
-           go-go-uber-org-goleak
-           go-golang-org-x-lint
-           go-honnef-co-go-tools))
+           go-go-uber-org-goleak))
     (propagated-inputs
-     (list go-github-com-benbjohnson-clock
-           go-github-com-pkg-errors
-           go-go-uber-org-atomic
-           go-go-uber-org-multierr
-           go-gopkg-in-yaml-v2))
+     (list go-go-uber-org-multierr
+           go-gopkg-in-yaml-v3))
     (home-page "https://pkg.go.dev/go.uber.org/zap";)
     (synopsis "Logging library for Go")
     (description

Reply via email to